@@ -77,6 +77,28 @@ def sort_season_data(df):
     return df_sorted
 
 
+def check_date(date: str):
+    """
+    Check if the date string entered is a valid date in the format %Y-%m-%d.
+    
+    Parameters
+    ----------
+    date: The date string to be checked.
+    
+    Returns
+    -------
+    Boolean, True if the date is valid, False otherwise.
+    """
+    
+    # Check to see if the date format entered can be interpretted as expected
+    try:
+        correct_date_format = bool(datetime.strptime(date, "%Y-%m-%d"))
+    except ValueError:
+        correct_date_format = False
+        
+    return correct_date_format
+
+
 def get_season_from_date(date):
     """
     Return the season in the format yyyy_yyyy from a date argument.
